# From meeting October 7, 2013

Agreed to

- be year 4 attachment
- on curriculum committee
- IT and science specific responsibilities


Science and ICT visits in this term...




- Complete forms fro Julia
